import { gRootTrackingTag } from '../interfaces/i_tracking_tag';
import { UtilityProcessMessageDestination, UtilityProcessMessageType, } from '../interfaces/i_utility_process';
var ProcessEvent;
(function (ProcessEvent) {
    ProcessEvent["Message"] = "message";
})(ProcessEvent || (ProcessEvent = {}));
export class CommunicationBackApi {
    rootTag = gRootTrackingTag;
    onDataReceivedListeners = new Set();
    onEventReceivedListeners = new Set();
    constructor() {
        process.parentPort.on(ProcessEvent.Message, (event) => {
            const message = event.data;
            const source = message.source;
            if (source !== UtilityProcessMessageDestination.Back) {
                return;
            }
            console.info('CommunicationBackApi: received a message event:\n', event);
            switch (message.type) {
                case UtilityProcessMessageType.Data: {
                    return this.onDataReceivedListeners.forEach(async (listener) => listener(message.data, {
                        fromTag: message.fromTag,
                        channel: message.channel,
                    }));
                }
                case UtilityProcessMessageType.Event: {
                    return this.onEventReceivedListeners.forEach(async (listener) => listener(message.event, {
                        fromTag: message.fromTag,
                        channel: message.channel,
                        data: message.data,
                    }));
                }
                default:
                    throw new Error('CommunicationBackApi: unexpected Message Type');
            }
        });
    }
    async sendData(data, args) {
        const message = {
            type: UtilityProcessMessageType.Data,
            destination: UtilityProcessMessageDestination.Back,
            data: data,
            toTags: args.toTags,
            channel: args.channel,
        };
        return process.parentPort.postMessage(message);
    }
    async onDataReceived(listener) {
        if (this.onDataReceivedListeners.has(listener)) {
            console.error('CommunicationBackApi: onDataReceived Listener already added');
            return;
        }
        this.onDataReceivedListeners.add(listener);
    }
    async unsetOnDataReceived(listener) {
        if (listener === undefined) {
            this.onDataReceivedListeners.clear();
            return;
        }
        if (!this.onDataReceivedListeners.has(listener)) {
            console.error("CommunicationBackApi: unable to unsetOnDataReceived, listener hasn't been added");
            return;
        }
        this.onDataReceivedListeners.delete(listener);
    }
    async sendEvent(event, args) {
        const message = {
            type: UtilityProcessMessageType.Event,
            destination: UtilityProcessMessageDestination.Back,
            event: event,
            toTags: args.toTags,
            channel: args.channel,
            data: args.data,
        };
        return process.parentPort.postMessage(message);
    }
    async onEventReceived(listener) {
        if (this.onEventReceivedListeners.has(listener)) {
            console.error('CommunicationBackApi: onEventReceived Listener already added');
            return;
        }
        this.onEventReceivedListeners.add(listener);
    }
    async unsetOnEventReceived(listener) {
        if (listener === undefined) {
            this.onEventReceivedListeners.clear();
            return;
        }
        if (!this.onEventReceivedListeners.has(listener)) {
            console.error("CommunicationBackApi: unable to unsetOnEventReceived, listener hasn't been added");
            return;
        }
        this.onEventReceivedListeners.delete(listener);
    }
}
