import { Api, ApiVersionState } from '../interfaces/i_api';
const gResponsePart = 'response';
const gResponseChannelPartsCount = 2;
export function convertToApi(convertApiName) {
    for (const apiName of Object.values(Api)) {
        if (convertApiName.toLowerCase() === apiName.toString().toLowerCase()) {
            return apiName;
        }
    }
    throw new Error(`Failed to convert "${convertApiName}" into Api type`);
}
export function getApiVersionState(versionLeft, versionRight) {
    if (versionLeft.major !== versionRight.major) {
        return ApiVersionState.Red;
    }
    if (versionLeft.minor !== versionRight.minor) {
        return ApiVersionState.Yellow;
    }
    return ApiVersionState.Green;
}
export function getReadableApiName(api) {
    switch (api) {
        case Api.AppInfo:
            return 'App Info API';
        case Api.AppMenu:
            return 'App Menu API';
        case Api.Cache:
            return 'Cache API';
        case Api.CodeEditor:
            return 'Code Editor API';
        case Api.Commands:
            return 'Commands API';
        case Api.Communication:
            return 'Communication API';
        case Api.ContextMenu:
            return 'Context Menu API';
        case Api.ControlPanel:
            return 'Control Panel API';
        case Api.Database:
            return 'Database API';
        case Api.ExtensionInfo:
            return 'Extension Info API';
        case Api.FileExplorer:
            return 'File Explorer API';
        case Api.FileSystem:
            return 'File System API';
        case Api.Hotkeys:
            return 'Hotkeys API';
        case Api.Lifecycle:
            return 'Lifecycle API';
        case Api.MainPanel:
            return 'Main Panel API';
        case Api.Node:
            return 'Node API';
        case Api.Notifications:
            return 'Notifications API';
        case Api.Path:
            return 'Path API';
        case Api.PingPong:
            return 'Ping Pong API';
        case Api.Processes:
            return 'Processes API';
        case Api.Settings:
            return 'Settings API';
        case Api.StatusBar:
            return 'Status Bar API';
        case Api.Storage:
            return 'Storage API';
        case Api.Tags:
            return 'Tags API';
        case Api.Web:
            return 'Web API';
    }
}
export function genApiRequestId() {
    return crypto.randomUUID();
}
export function getApiResponseChannel(requestId) {
    return `${gResponsePart}.${requestId}`;
}
export function isApiResponseChannel(channel) {
    const parts = channel.split('.');
    if (parts.length !== gResponseChannelPartsCount) {
        return false;
    }
    return parts[0] === gResponsePart;
}
export function parseApiRequestId(channel) {
    if (!isApiResponseChannel(channel)) {
        throw new Error(`Provided channel "${channel}" is not an Api Response Channel`);
    }
    const [response, requestId] = channel.split('.');
    return requestId;
}
