export class ApiListenersController {
    _listeners = new Map();
    addListener(listener, args) {
        const channelListeners = (() => {
            if (!this._listeners.has(args.channel)) {
                this._listeners.set(args.channel, new Map());
            }
            return this._listeners.get(args.channel);
        })();
        if (channelListeners.has(listener)) {
            throw new Error(`ApiRequestListener "${listener}" already exists for the channel "${args.channel}"`);
        }
        const listenerId = crypto.randomUUID();
        channelListeners.set(listener, listenerId);
        return listenerId;
    }
    getListenerId(listener, args) {
        const channelListeners = this._listeners.get(args.channel);
        if (channelListeners === undefined) {
            throw new Error(`Listeners storage for channel "${args.channel}" doesn't exist`);
        }
        const listenerId = channelListeners.get(listener);
        if (listenerId === undefined) {
            throw new Error(`ApiRequestListener "${listener}" doesn't exist for the channel "${args.channel}"`);
        }
        return listenerId;
    }
    removeListener(listener, args) {
        const channelListeners = this._listeners.get(args.channel);
        if (channelListeners === undefined) {
            throw new Error(`Listeners storage for channel "${args.channel}" doesn't exist`);
        }
        if (!channelListeners.has(listener)) {
            throw new Error(`ApiRequestListener "${listener}" doesn't exist`);
        }
        channelListeners.delete(listener);
    }
    removeAllListeners(args) {
        const channelListeners = this._listeners.get(args.channel);
        if (channelListeners === undefined) {
            throw new Error(`Listeners storage for channel "${args.channel}" doesn't exist`);
        }
        channelListeners.clear();
    }
}
