import { ApiPreloadListenersController } from '../classes/api_preload_listeners_controller';
import { genApiRequestId, getApiResponseChannel } from '../classes/api_helper';
const gRequestTimeout = 1000;
const gRequestTimeoutResult = crypto.randomUUID();
export class PreloadApiBase {
    _ipcRenderer;
    _preloadListenersController = new ApiPreloadListenersController();
    constructor(ipcRenderer) {
        this._ipcRenderer = ipcRenderer;
    }
    async _sendRequestPromise(channel, ...payload) {
        const requestPromise = new Promise((resolve) => {
            const requestId = genApiRequestId();
            const preloadListener = (event, ...eventArgs) => {
                const [requestChannel, requestId, result] = eventArgs;
                resolve(result);
            };
            this._ipcRenderer.once(getApiResponseChannel(requestId), preloadListener);
            this._ipcRenderer.sendToHost(channel, requestId, ...payload);
        });
        const timeoutPromise = new Promise((resolve) => setTimeout(() => {
            resolve(gRequestTimeoutResult);
        }, gRequestTimeout));
        const result = await Promise.race([requestPromise, timeoutPromise]);
        if (result === gRequestTimeoutResult) {
            throw new Error('Request Timeout');
        }
        return result;
    }
    _addListener(listener, args) {
        const preloadListener = (event, ...eventArgs) => {
            const [requestId, ...payload] = eventArgs;
            const result = listener(...payload);
            this._ipcRenderer.sendToHost(getApiResponseChannel(requestId), args.channel, requestId, result);
        };
        if (args.listenerId === undefined) {
            this._ipcRenderer.once(args.channel, preloadListener);
        }
        else {
            this._preloadListenersController.addPreloadListener(preloadListener, {
                channel: args.channel,
                listenerId: args.listenerId,
            });
            this._ipcRenderer.on(args.channel, preloadListener);
        }
    }
    _removeListener(args) {
        if (args.listenerId === undefined) {
            this._preloadListenersController.removeAllPreloadListeners({
                channel: args.channel,
            });
            this._ipcRenderer.removeAllListeners(args.channel);
        }
        else {
            const preloadListener = this._preloadListenersController.removePreloadListener({
                channel: args.channel,
                listenerId: args.listenerId,
            });
            this._ipcRenderer.removeListener(args.channel, preloadListener);
        }
    }
}
