import { EntityType } from '../interfaces/i_entity';
import { IPathAndUrl } from '../interfaces/i_path_and_url';
import { IExtCPTabButtonsDelegate, IIntCPTabButtonsDelegate } from '../interfaces/i_cp_tab_buttons_delegate';
import { IExtCPTabSectionsDelegate, IIntCPTabSectionsDelegate } from '../interfaces/i_cp_tab_sections_delegate';
import { IWebviewDelegate } from '../interfaces/i_webview_delegate';
import { IEntityLifecycle } from '../interfaces/i_entity_lifecycle';
import { IExtEntity } from '../interfaces/i_ext_entity';
import { IDestructable } from '../interfaces/i_destructable';
import { IResettable } from '../interfaces/i_resettable';
export type CPTabId = string;
export interface ICPTabBase extends IDestructable, IResettable, IEntityLifecycle {
    readonly entityType: EntityType;
    readonly id: CPTabId;
    readonly title: string;
    readonly iconContent?: string;
    readonly createdDate: Date;
}
export declare enum IntCPTabType {
    ExtensionsInfo = "extensionsInfo",
    Sections = "sections"
}
export interface IIntCPTabBase extends ICPTabBase, IIntCPTabButtonsDelegate {
    readonly entityType: EntityType.Int;
    readonly type: IntCPTabType;
}
export interface IIntCPTabWithExtensionsInfo extends IIntCPTabBase {
    readonly type: IntCPTabType.ExtensionsInfo;
}
export interface IIntCPTabWithSections extends IIntCPTabBase, IIntCPTabSectionsDelegate {
    readonly type: IntCPTabType.Sections;
}
export type IIntCPTab = IIntCPTabWithExtensionsInfo | IIntCPTabWithSections;
export declare enum ExtCPTabType {
    Html = "html",
    Sections = "sections"
}
export interface IExtCPTabBase extends ICPTabBase, IExtEntity, IExtCPTabButtonsDelegate {
    readonly entityType: EntityType.Ext;
    readonly type: ExtCPTabType;
}
export interface IExtCPTabWithHtml extends IExtCPTabBase, IWebviewDelegate {
    readonly type: ExtCPTabType.Html;
    readonly htmlPathAndUrl: IPathAndUrl;
    readonly nodeScriptPath?: string;
    readonly initData?: any;
}
export interface IExtCPTabWithSections extends IExtCPTabBase, IWebviewDelegate, IExtCPTabSectionsDelegate {
    readonly type: ExtCPTabType.Sections;
    readonly scriptPath?: string;
    readonly nodeScriptPath?: string;
    readonly initData?: any;
}
export type IExtCPTab = IExtCPTabWithHtml | IExtCPTabWithSections;
export type ICPTab = IIntCPTab | IExtCPTab;
export type ICPTabWithSections = IIntCPTabWithSections | IExtCPTabWithSections;
