import { ExtensionImplementableApis, IExtensionPackageInfo, ExtensionRequirableApis } from '../interfaces/i_extension_package_info';
import { Api, IApiVersionInfo, ImplementableApi } from '../interfaces/i_api';
import { IWebviewController } from '../interfaces/i_webview_controller';
import { IExtCPTab } from '../interfaces/i_cp_tab';
import { IExtensionTagsController } from '../interfaces/i_extension_tags_controller';
import { IExtensionInfo, IExtensionInfoInvalid } from '../interfaces/i_extension_info';
import { TrackingTag } from '../interfaces/i_tracking_tag';
export type ExtensionId = string;
export declare enum ExtensionState {
    Available = "available",
    Installing = "installing",
    Enabled = "enabled",
    Mounted = "mounted",
    Disabled = "disabled",
    Removing = "removing",
    MarkedForRemoval = "markedForRemoval",
    Removed = "removed",
    Invalid = "invalid"
}
export interface IExtension extends IExtensionInfo {
    readonly id: ExtensionId;
    readonly packageInfo: IExtensionPackageInfo;
    readonly filePath: string;
    readonly iconContent?: string;
    readonly isDebug: boolean;
    readonly apiVersionInfo: IApiVersionInfo;
    readonly tagsController: IExtensionTagsController;
    getState(): ExtensionState;
    isAvailable(): boolean;
    isInstalling(): boolean;
    isInstalled(): boolean;
    isEnabled(): boolean;
    isMounted(): boolean;
    isDisabled(): boolean;
    isRemoving(): boolean;
    isMarkedForRemoval(): boolean;
    isRemoved(): boolean;
    isInvalid(): boolean;
    canBeInstalled(): boolean;
    canBeEnabled(): boolean;
    canBeDisabled(): boolean;
    canBeMounted(): boolean;
    canBeUnmounted(): boolean;
    canBeMarkedForRemoval(): boolean;
    canBeMarkedInvalid(): boolean;
    canBeRemoved(): boolean;
    enable(): void;
    disable(): void;
    mount(): void;
    unmount(): Promise<void>;
    markRemoving(): void;
    markForRemoval(): void;
    markRemoved(): void;
    markInvalid(): void;
    getInitialCPTabs(): Promise<Set<IExtCPTab>>;
    getRequiredApis(): ExtensionRequirableApis;
    getImplementedApis(): ExtensionImplementableApis | undefined;
    isApiRequired(api: Api): boolean;
    isApiImplemented(api: ImplementableApi): boolean;
    addWebviewController(args: {
        tag: TrackingTag;
        controller: IWebviewController;
    }): void;
    hasWebviewController(tag: TrackingTag): boolean;
    removeWebviewController(tag: TrackingTag): void;
    sendBasicDataToWebviews(data: any, args: {
        fromTag: TrackingTag;
        channel?: string;
        toTags?: TrackingTag[];
    }): Promise<void>;
    sendBasicEventToWebviews(name: string, args: {
        fromTag: string;
        channel?: string;
        data?: any;
        toTags?: TrackingTag[];
    }): Promise<void>;
    sendNodeDataToWebviews(data: any, args: {
        fromTag: TrackingTag;
        channel?: string;
        toTags?: TrackingTag[];
    }): Promise<void>;
    sendNodeEventToWebviews(name: string, args: {
        fromTag: string;
        channel?: string;
        data?: any;
        toTags?: TrackingTag[];
    }): Promise<void>;
}
export interface IExtensionInvalid extends IExtensionInfoInvalid {
    readonly id: ExtensionId;
    readonly fileName: string;
    readonly filePath: string;
    readonly isDebug: boolean;
}
export declare enum ExtensionStyleTarget {
    CPTab = "CPTab",
    CPTabSection = "CPTabSection",
    Popup = "Popup",
    MPTab = "MPTab"
}
