export type JsonStorageKey = string;
export type JsonStorageValue = any;
export interface IJsonStorageMap {
    clear(): Promise<void>;
    has(key: JsonStorageKey): Promise<boolean>;
    get<T>(key: JsonStorageKey): Promise<T | undefined>;
    set(args: {
        key: JsonStorageKey;
        value: JsonStorageValue;
        encrypt?: boolean;
    }): Promise<void>;
    delete(key: JsonStorageKey): Promise<void>;
    getMapClone(): Promise<Map<JsonStorageKey, JsonStorageValue>>;
    getDecryptedMapClone(): Promise<Map<JsonStorageKey, JsonStorageValue>>;
    update(newMap: Map<JsonStorageKey, JsonStorageValue>): Promise<void>;
}
export interface IJsonStorageSet {
    clear(): Promise<void>;
    has(value: JsonStorageValue): Promise<boolean>;
    add(value: JsonStorageValue, args?: {
        encrypt?: boolean;
    }): Promise<void>;
    delete(value: JsonStorageValue): Promise<void>;
    getSetClone(): Promise<Set<JsonStorageValue>>;
    getDecryptedSetClone(): Promise<Set<JsonStorageValue>>;
    update(newSet: Set<JsonStorageValue>): Promise<void>;
}
export interface IJsonStorageArray {
    clear(): Promise<void>;
    includes(item: JsonStorageValue, fromIndex?: number): Promise<boolean>;
    at<T>(index: number): Promise<T | undefined>;
    push(item: JsonStorageValue, args?: {
        encrypt?: boolean;
    }): Promise<void>;
    splice(start: number, deleteCount?: number): Promise<void>;
    getArrayClone(): Promise<JsonStorageValue[]>;
    getDecryptedArrayClone(): Promise<JsonStorageValue[]>;
    update(newArray: JsonStorageValue[]): Promise<void>;
}
