import { IReactiveFile } from '../interfaces/i_reactive_file';
import { IExtensionInfo, IExtensionInfoInvalid } from '../interfaces/i_extension_info';
import { IPathAndUrl } from '../interfaces/i_path_and_url';
import { EntityType } from '../interfaces/i_entity';
import { IEntityLifecycle } from '../interfaces/i_entity_lifecycle';
import { IExtEntity } from '../interfaces/i_ext_entity';
import { IWebviewDelegate } from '../interfaces/i_webview_delegate';
import { IDestructable } from '../interfaces/i_destructable';
import { IResettable } from '../interfaces/i_resettable';
export type MPTabId = string;
export interface IMPTabBase extends IDestructable, IResettable, IEntityLifecycle {
    readonly entityType: EntityType;
    readonly id: MPTabId;
    readonly title: string;
    readonly createdDate: Date;
    isChanged(): boolean;
}
export declare enum IntMPTabType {
    File = "file",
    Settings = "settings",
    ExtensionInfo = "extensionInfo"
}
export interface IIntMPTabBase extends IMPTabBase {
    readonly entityType: EntityType.Int;
    readonly type: IntMPTabType;
}
export interface IIntMPTabWithFile extends IIntMPTabBase {
    readonly type: IntMPTabType.File;
    file(): IReactiveFile;
}
export interface IIntMPTabWithSettings extends IIntMPTabBase {
    readonly type: IntMPTabType.Settings;
    file(): IReactiveFile;
}
export interface IIntMPTabWithExtensionInfo extends IIntMPTabBase {
    readonly type: IntMPTabType.ExtensionInfo;
    readonly extensionInfo: IExtensionInfo | IExtensionInfoInvalid;
}
export type IIntMPTab = IIntMPTabWithFile | IIntMPTabWithSettings | IIntMPTabWithExtensionInfo;
export declare enum ExtMPTabType {
    Html = "html"
}
export interface IExtMPTabBase extends IMPTabBase, IExtEntity {
    readonly entityType: EntityType.Ext;
    readonly type: ExtMPTabType;
}
export interface IExtMPTabWithHtml extends IExtMPTabBase, IWebviewDelegate {
    readonly type: ExtMPTabType.Html;
    readonly htmlPathAndUrl: IPathAndUrl;
    readonly nodeScriptPath?: string;
    readonly initData?: any;
}
export type IExtMPTab = IExtMPTabWithHtml;
export type IMPTab = IIntMPTab | IExtMPTab;
