import { JsonStorageKey, JsonStorageValue } from '../interfaces/i_json_storage';
import { ApiInfoType } from '../interfaces/i_api_info';
import { Api } from '../interfaces/i_api';
export declare namespace storageApiInfo {
    const api = Api.Storage;
    const apiInfoType = ApiInfoType.Main;
    enum Channel {
        Has = "storageApi.has",
        Get = "storageApi.get",
        Set = "storageApi.set",
        OnSet = "storageApi.onSet",
        Delete = "storageApi.delete",
        OnDeleted = "storageApi.onDeleted",
        GetAll = "storageApi.getAll",
        Clear = "storageApi.clear",
        OnCleared = "storageApi.onCleared",
        OnChanged = "storageApi.onChanged"
    }
    namespace has {
        const channel = Channel.Has;
        type ArgsType = [key: JsonStorageKey];
        type ResultType = boolean;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace get {
        const channel = Channel.Get;
        type ArgsType = [key: JsonStorageKey];
        type ResultType = JsonStorageValue | undefined;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace set {
        const channel = Channel.Set;
        type InnerArgsType = {
            key: JsonStorageKey;
            value: JsonStorageValue;
            encrypt?: boolean;
        };
        type ArgsType = [args: InnerArgsType];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace onSet {
        const channel = Channel.OnSet;
        namespace listener {
            type InnerArgsType = {
                key: JsonStorageKey;
                oldValue: JsonStorageValue;
                newValue: JsonStorageValue;
            };
            type ArgsType = [record: InnerArgsType];
            type ResultType = void;
            type ReturnType = ResultType | Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
        type ListenerType = listener.FunctionType;
        type InnerArgsType = {
            isOnce?: boolean;
        } | undefined;
        type ArgsType = [listener: ListenerType, args?: InnerArgsType];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
        namespace unset {
            type ListenerType = listener.FunctionType | undefined;
            type ArgsType = [listener?: ListenerType];
            type ResultType = void;
            type ReturnType = Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
    }
    namespace delete_ {
        const channel = Channel.Delete;
        type ArgsType = [key: JsonStorageKey];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace onDeleted {
        const channel = Channel.OnDeleted;
        namespace listener {
            type InnerArgsType = {
                key: JsonStorageKey;
                value: JsonStorageValue;
            };
            type ArgsType = [deletedRecord: InnerArgsType];
            type ResultType = void;
            type ReturnType = ResultType | Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
        type ListenerType = listener.FunctionType;
        type InnerArgsType = {
            isOnce?: boolean;
        } | undefined;
        type ArgsType = [listener: ListenerType, args?: InnerArgsType];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
        namespace unset {
            type ListenerType = listener.FunctionType | undefined;
            type ArgsType = [listener?: ListenerType];
            type ResultType = void;
            type ReturnType = Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
    }
    namespace getAll {
        const channel = Channel.GetAll;
        type ArgsType = [];
        type ResultType = Map<JsonStorageKey, JsonStorageValue>;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace clear {
        const channel = Channel.Clear;
        type ArgsType = [];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
    }
    namespace onCleared {
        const channel = Channel.OnCleared;
        namespace listener {
            type ArgsType = [records: Map<JsonStorageKey, JsonStorageValue>];
            type ResultType = void;
            type ReturnType = ResultType | Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
        type ListenerType = listener.FunctionType;
        type InnerArgsType = {
            isOnce?: boolean;
        } | undefined;
        type ArgsType = [listener: ListenerType, args?: InnerArgsType];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
        namespace unset {
            type ListenerType = listener.FunctionType | undefined;
            type ArgsType = [listener?: ListenerType];
            type ResultType = void;
            type ReturnType = Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
    }
    namespace onChangeed {
        const channel = Channel.OnChanged;
        namespace listener {
            type InnerArgsType = Map<JsonStorageKey, {
                oldValue: JsonStorageValue;
                newValue: JsonStorageValue;
            }>;
            type ArgsType = [changedRecords: InnerArgsType];
            type ResultType = void;
            type ReturnType = ResultType | Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
        type ListenerType = listener.FunctionType;
        type InnerArgsType = {
            isOnce?: boolean;
        } | undefined;
        type ArgsType = [listener: ListenerType, args?: InnerArgsType];
        type ResultType = void;
        type ReturnType = Promise<ResultType>;
        type FunctionType = (...args: ArgsType) => ReturnType;
        namespace unset {
            type ListenerType = listener.FunctionType | undefined;
            type ArgsType = [listener?: ListenerType];
            type ResultType = void;
            type ReturnType = Promise<ResultType>;
            type FunctionType = (...args: ArgsType) => ReturnType;
        }
    }
}
